IWA Terminal

## Accounts on Gnosis

Track Tokens:

Tag | Address | Type
--- | --- | ---

### Send Transaction

From
To
Amount
Token

## Recent Activity on Gnosis

Time | Chain | From | To | Token | Amount | Value (€) | Status | Hash | Gas (Wei) | Gas (€) | Tags
--- | --- | --- | --- | --- | --- | --- | --- | --- | --- | --- | ---

## Olas Services on Gnosis

No Olas services found for this chain.

Account

### Token Swap on Gnosis

Sell exact amount Buy exact amount
Sell
Buy

### Wrap / Unwrap

Wrap xDAI → WXDAI Unwrap WXDAI → xDAI
Amount

### Recent Orders on Gnosis

Date | Order ID | Status | Sell | Buy | Expiring in
--- | --- | --- | --- | --- | ---
Loading orders...

## Staking Rewards

### Monthly Rewards

### Cumulative Rewards

### Rewards by Trader

### OLAS Price at Claim Time

### Claim History

Date | Service | OLAS | Price (EUR) | Value (EUR) | Tx
--- | --- | --- | --- | --- | ---
Loading claims...

## Node Connectivity

## Olas Network

### Agent Blueprints on Ethereum

ID | Public ID | Description | Owner | Pkg Hash | Block
--- | --- | --- | --- | --- | ---
Loading...

### Components on Ethereum

ID | Public ID | Type | Description | Owner | Pkg Hash | Block
--- | --- | --- | --- | --- | --- | ---
Loading...

### Builders on Ethereum

Address
Loading...

### Agents on Ethereum

ID | Public ID | State | Agent IDs | Threshold | Owner
--- | --- | --- | --- | --- | ---
Loading...

### Agents on Gnosis

ID | Multisig | Agents | Creator | Created | Config Hash
--- | --- | --- | --- | --- | ---
Select a chain to load data

### Staking Contracts on Gnosis

Address | Max Services | Rewards/s (OLAS) | Min Deposit (OLAS) | Liveness (s) | Agents | Inactivity Periods
--- | --- | --- | --- | --- | --- | ---
Select a chain to load data

### Checkpoints on Gnosis

Epoch | Contract | Available Rewards | Services | Block | Time | Tx
--- | --- | --- | --- | --- | --- | ---
Select a chain to load data

### Staking Events on Gnosis

Type | Epoch | Service | Address | Amount (OLAS) | Time | Tx
--- | --- | --- | --- | --- | --- | ---
Select a chain to load data

### Daily Staking Trends on Gnosis

Date | # Services | Total Rewards (OLAS) | Median Cumulative (OLAS)
--- | --- | --- | ---
Select a chain to load data

### Top Token Holders on Gnosis

Rank | Address | Balance (OLAS) | %
--- | --- | --- | ---
Loading...

### Recent Transfers on Gnosis

From | To | Value (OLAS) | Block | Time | Tx
--- | --- | --- | --- | --- | ---
Loading...

## Create Multisig Safe

Tag Name
Threshold (Signatures needed)
Select Owners
Chains (Select at least one)

## Create EOA Account

Tag Name (optional)

## Confirm Action

## Stake Service

Select a staking contract for this service:

Staking Contract
Loading contracts...

## Create Olas Service

Service Name
Chain
Agent Type
Staking Contract
Loading contracts...

## Fund Service

Send native tokens from master wallet to service accounts:

Agent Amount (xDAI)
Safe Amount (xDAI)

## ⚠️ Terminate Service

This action will:
• Unstake the service (if staked)
• Terminate the service
• Unbond all operators
The service will return to PRE_REGISTRATION state.

## 🔐 Authentication Required

Enter your Web UI password to continue:

Password